@@ -9,7 +9,6 @@ from ..launcher_settings import LauncherSettings
 
 
 class LastVariants(object):
-
     def __init__(self):
         self.cache = {}
         LauncherSignal.add_listener("quit", self)
@@ -23,7 +22,6 @@ class LastVariants(object):
 
 # class VariantsBrowser(fsui.VerticalItemView):
 class VariantsBrowser(fsui.ItemChoice):
-
     @staticmethod
     def use_horizontal_layout():
         # return fsui.get_screen_size()[0] > 1024
@@ -44,28 +42,24 @@ class VariantsBrowser(fsui.ItemChoice):
         self.hd_icon = fsui.Image("launcher:res/hd_game_16.png")
         # self.missing_icon = fsui.Image(
         #     "launcher:res/missing_game_16.png")
-        self.missing_icon = fsui.Image(
-            "launcher:res/16/delete_grey.png")
-        self.missing_color = fsui.Color(0xa8, 0xa8, 0xa8)
+        self.missing_icon = fsui.Image("launcher:res/16x16/delete_grey.png")
+        self.missing_color = fsui.Color(0xA8, 0xA8, 0xA8)
 
-        self.blank_icon = fsui.Image(
-            "launcher:res/16/blank.png")
-        self.bullet_icon = fsui.Image(
-            "launcher:res/16/bullet.png")
+        self.blank_icon = fsui.Image("launcher:res/16x16/blank.png")
+        self.bullet_icon = fsui.Image("launcher:res/16x16/bullet.png")
 
         self.manual_download_icon = fsui.Image(
-            "launcher:res/16/arrow_down_yellow.png")
+            "launcher:res/16x16/arrow_down_yellow.png"
+        )
         self.auto_download_icon = fsui.Image(
-            "launcher:res/16/arrow_down_green.png")
+            "launcher:res/16x16/arrow_down_green.png"
+        )
 
-        self.up_icon = fsui.Image(
-            "launcher:res/16/thumb_up_mod.png")
-        self.down_icon = fsui.Image(
-            "launcher:res/16/thumb_down_mod.png")
+        self.up_icon = fsui.Image("launcher:res/16x16/thumb_up_mod.png")
+        self.down_icon = fsui.Image("launcher:res/16x16/thumb_down_mod.png")
         self.fav_icon = fsui.Image("launcher:res/rating_fav_16.png")
 
         LauncherSettings.add_listener(self)
-        LauncherConfig.add_listener(self)
         self.on_setting("parent_uuid", LauncherSettings.get("parent_uuid"))
 
     def on_destroy(self):
@@ -80,8 +74,9 @@ class VariantsBrowser(fsui.ItemChoice):
 
     # noinspection PyMethodMayBeStatic
     def on_activate_item(self, _):
-        from ..fs_uae_launcher import FSUAELauncher
-        FSUAELauncher.start_game()
+        from ..launcherapp import LauncherApp
+
+        LauncherApp.start_game()
 
     def on_setting(self, key, value):
         if key == "parent_uuid":
@@ -93,14 +88,13 @@ class VariantsBrowser(fsui.ItemChoice):
                 # self.set_items([gettext("Configuration")])
                 self.set_items([])
                 self.disable()
-
-    def on_config(self, key, value):
-        if key == "variant_rating":
+        elif key == "__variant_rating":
             variant_uuid = LauncherConfig.get("variant_uuid")
             for item in self.items:
                 if item["uuid"] == variant_uuid:
                     item["personal_rating"] = int(value or 0)
                     self.update()
+                    break
 
     def set_items(self, items):
         self.items = items
@@ -176,29 +170,35 @@ class VariantsBrowser(fsui.ItemChoice):
         items = database.find_game_variants_new(game_uuid, have=0)
 
         # items = database.search_configurations(self.search)
-        # FIXME: Merge code with FSGameSystemContext.py
+        # FIXME: Merge code with
+        # FSGameSystemContext.py:get_ordered_game_variants
         sortable_items = []
         for i, variant in enumerate(items):
             name = variant["name"]
-
-            name = name.replace("\nAmiga \u00b7 ", "\n")
-            # print(name, variant[3])
-            # name = name.replace("\nCD32 \u00b7 ", "\n")
-            # name = variant[1].replace("\n", " \u00b7 ")
-
+            # assert "\n" not in name
             # only show variant name (without game name)
-            name = name.split("\n", 1)[-1]
+            # name = name.split("\n", 1)[-1]
 
             game_database = fsgs.game_database(variant["database"])
-            variant["like_rating"], variant["work_rating"] = \
-                game_database.get_ratings_for_game(variant["uuid"])
-            variant["personal_rating"], ignored = \
-                database.get_ratings_for_game(variant["uuid"])
+            variant["like_rating"], variant[
+                "work_rating"
+            ] = game_database.get_ratings_for_game(variant["uuid"])
+            variant[
+                "personal_rating"
+            ], ignored = database.get_ratings_for_game(variant["uuid"])
 
-            sort_key = (0, 1000000 - variant["like_rating"],
-                        1000000 - variant["work_rating"], name)
-            sortable_items.append(
-                (sort_key, i, variant))
+            if variant["published"] == 0:
+                primary_sort = 1
+                variant["name"] = "[UNPUBLISHED] " + variant["name"]
+            else:
+                primary_sort = 0
+            sort_key = (
+                primary_sort,
+                1000000 - variant["like_rating"],
+                1000000 - variant["work_rating"],
+                name,
+            )
+            sortable_items.append((sort_key, i, variant))
         # print(sortable_items)
         self.items = [x[2] for x in sorted(sortable_items)]
         self.update()
@@ -211,9 +211,11 @@ class VariantsBrowser(fsui.ItemChoice):
         list_uuid = LauncherSettings.get("game_list_uuid")
         if list_uuid:
             list_variant_uuid = database.get_variant_for_list_and_game(
-                list_uuid, game_uuid)
-            print("game list", list_uuid, "override variant",
-                  list_variant_uuid)
+                list_uuid, game_uuid
+            )
+            print(
+                "game list", list_uuid, "override variant", list_variant_uuid
+            )
         else:
             list_variant_uuid = None
         if list_variant_uuid:
@@ -228,8 +230,13 @@ class VariantsBrowser(fsui.ItemChoice):
             # default index selection
             for i, variant in enumerate(self.items):
                 if variant["personal_rating"] == 5:
-                    select_index = i
-                    break
+                    if variant["have"] >= 3:
+                        select_index = i
+                        break
+                    else:
+                        # FIXME: Add warning here that the favorite variant
+                        # could not be selected.
+                        pass
             else:
                 for i, variant in enumerate(self.items):
                     if variant["have"] >= 3:
@@ -274,9 +281,7 @@ class VariantsBrowser(fsui.ItemChoice):
         except Exception:
             traceback.print_exc()
             LauncherConfig.load_default_config()
-            LauncherConfig.load({
-                "__error": "Error Loading Configuration"
-            })
+            LauncherConfig.load({"__error": "Error Loading Configuration"})
             self.select_item(None)
 
     def _load_variant(self, item):
@@ -286,10 +291,12 @@ class VariantsBrowser(fsui.ItemChoice):
         personal_rating = item["personal_rating"]
         have = item["have"]
         self._load_variant_2(
-                variant_uuid, database_name, personal_rating, have)
+            variant_uuid, database_name, personal_rating, have
+        )
 
     def _load_variant_2(
-            self, variant_uuid, database_name, personal_rating, have):
+        self, variant_uuid, database_name, personal_rating, have
+    ):
         if LauncherConfig.get("variant_uuid") == variant_uuid:
             print("Variant {} is already loaded".format(variant_uuid))
         game_database = fsgs.game_database(database_name)
@@ -315,9 +322,10 @@ class VariantsBrowser(fsui.ItemChoice):
         # values["variant_uuid"] = variant_uuid
         # values["variant_rating"] = str(item["personal_rating"])
 
-        print(values)
         LauncherConfig.load_values(values, uuid=variant_uuid)
 
+        # print("--->", LauncherConfig.get("variant_uuid"))
+
         # variant_rating = 0
         # if item["work_rating"] is not None:
         #     variant_rating = item["work_rating"] - 2
@@ -325,11 +333,12 @@ class VariantsBrowser(fsui.ItemChoice):
         #     variant_rating = item["like_rating"]
         # Config.set("__variant_rating", str(variant_rating))
 
-        LauncherConfig.set("variant_uuid", variant_uuid)
-        LauncherConfig.set("variant_rating", str(personal_rating))
+        # LauncherConfig.set("variant_uuid", variant_uuid)
         LauncherConfig.set("__changed", "0")
         LauncherConfig.set("__database", database_name)
 
+        LauncherSettings.set("__variant_rating", str(personal_rating))
+
         if int(have) < self.AVAILABLE:
             print(" -- some files are missing --")
             LauncherConfig.set("x_missing_files", "1")
