@@ -8,7 +8,7 @@
 
 void fs_ref_initialize(void *ptr, void (*destroy_function)(void *ptr))
 {
-    struct fs_ref *ref = ptr;
+    struct fs_ref *ref = (struct fs_ref *) ptr;
     ref->magic = FS_REF_MAGIC;
     ref->count = 1;
     ref->destroy = destroy_function;
@@ -16,14 +16,14 @@ void fs_ref_initialize(void *ptr, void (*destroy_function)(void *ptr))
 
 int fs_ref(void *ptr)
 {
-    struct fs_ref *ref = ptr;
+    struct fs_ref *ref = (struct fs_ref *) ptr;
     ref->count += 1;
     return ref->count;
 }
 
 int fs_unref(void *ptr)
 {
-    struct fs_ref* ref = ptr;
+    struct fs_ref* ref = (struct fs_ref *) ptr;
     if (ref->magic != FS_REF_MAGIC) {
         fs_log("ERROR: not UNREF'ING fs-ref struct\n");
         return -1;
