@@ -1,9 +1,7 @@
 #ifndef UAE_DONGLE_H
 #define UAE_DONGLE_H
 
-#ifdef FSUAE // NL
 #include "uae/types.h"
-#endif
 
 extern void dongle_reset (void);
 extern uae_u8 dongle_cia_read (int, int, uae_u8);
@@ -14,4 +12,4 @@ extern void dongle_potgo (uae_u16);
 extern uae_u16 dongle_potgor (uae_u16);
 extern int dongle_analogjoy (int, int);
 
-#endif // UAE_DONGLE_H
+#endif /* UAE_DONGLE_H */
