@@ -9,9 +9,8 @@
 #ifndef UAE_ZFILE_H
 #define UAE_ZFILE_H
 
-#ifdef FSUAE // NL
 #include "uae/types.h"
-#include "zfile.h"
+#ifdef FSUAE
 #include <stddef.h>
 #endif
 
@@ -162,4 +161,4 @@ struct mystat
 extern void timeval_to_amiga (struct mytimeval *tv, int* days, int* mins, int* ticks, int tickcount);
 extern void amiga_to_timeval (struct mytimeval *tv, int days, int mins, int ticks, int tickcount);
 
-#endif // UAE_ZFILE_H
+#endif /* UAE_ZFILE_H */
